pub struct DaryHeapU32 {
root: u32,
blocks: Vec<HeapBlock<u32, 16>>,
len: usize,
backend: SimdBackend,
}Expand description
A cache-line-oriented 16-ary max-heap for medium-to-large 32-bit heaps. BinaryHeap can be faster for small heaps and monotone replacements.
Fields
root: u32blocks: Vec<HeapBlock<u32, 16>>len: usizebackend: SimdBackendImplementations
Sourceimpl DaryHeapU32
impl DaryHeapU32
pub fn new() -> Self
pub fn with_capacity(capacity: usize) -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn peek(&self) -> Option<u32>
pub fn push(&mut self, value: u32)
pub fn pop(&mut self) -> Option<u32>
Sourcepub fn replace(&mut self, value: u32) -> Option<u32>
pub fn replace(&mut self, value: u32) -> Option<u32>
Unconditionally replaces the greatest value, or inserts into an empty heap.
pub fn clear(&mut self)
pub fn into_sorted_vec(self) -> Vec<u32>
fn empty(capacity: usize, backend: SimdBackend) -> Self
fn build(values: Vec<u32>, backend: SimdBackend) -> Self
fn encode(value: u32) -> u32
fn decode(value: u32) -> u32
fn key(&self, index: usize) -> u32
fn set_key(&mut self, index: usize, value: u32)
fn sift_down_by<F>(&mut self, hole: usize, value: u32, max_index: F)
fn heapify(&mut self)
Sourceimpl DaryHeapU32
impl DaryHeapU32
fn sift_down_scalar(&mut self, hole: usize, value: u32)
unsafe fn sift_down_avx2(&mut self, hole: usize, value: u32)
unsafe fn sift_down_avx512(&mut self, hole: usize, value: u32)
fn sift_down(&mut self, hole: usize, value: u32)
fn sift_down_after_pop(&mut self, hole: usize, value: u32)